@@ -10,6 +10,9 @@ pub enum Error {
   FileNotFound(String),
   IsADirectory(String),
   IsAbsolute(String),
+  InvalidHostId(String),
+  InvalidHostTag(String),
+  InvalidToken(String),
 }
 
 impl Display for Error {
