@@ -1,4 +1,4 @@
-use crate::core::{Result, Error, Host};
+use crate::core::{Result, Error, Host, HostId, eval_tag_expr};
 use serde_derive::{Serialize, Deserialize};
 
 use is_executable::IsExecutable;
@@ -98,33 +98,30 @@ impl Inventory {
 
   /// Remove host from the inventory or do nothing if the host's ID was not
   /// found.
-  pub fn remove_host(&mut self, host_id: String) -> &mut Self {
+  pub fn remove_host(&mut self, host_id: HostId) -> &mut Self {
     self.hosts.retain(|host| host.id != host_id);
     self
   }
 
   /// Get `Some(host)` by its ID, or `None` if it does not exist.
-  pub fn get_host_by_id(&self, id: String) -> Option<Host> {
+  pub fn get_host_by_id(&self, id: HostId) -> Option<Host> {
     self.hosts.iter()
       .find(|host| host.id == id)
       .map(|host| host.clone())
   }
 
-  /// Get a list of host matching at least on of the provided tags.
-  pub fn get_hosts_by_tags(&self, tags: Vec<String>) -> Vec<Host> {
-    self.hosts
-      .iter()
-      .filter(|host| {
-        for tag in tags.iter() {
-          if host.tags.contains(tag) {
-            return true
-          }
-        }
+  /// Get a list of host matching the tag expression.
+  pub fn get_hosts_by_tags(&self, tag_expr: String) -> Result<Vec<Host>> {
+    let mut hosts = vec![];
 
-        return false
-      })
-      .map(|host| host.clone())
-      .collect()
+    for host in self.hosts.iter() {
+      let tags = host.tags.iter().map(|tag| tag.clone().to_string()).collect();
+      if eval_tag_expr(&tag_expr, tags)? {
+        hosts.push(host.clone());
+      }
+    }
+
+    Ok(hosts)
   }
 }
 
